@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  *
- $Id: battstat_applet.c 11222 2009-01-26 05:41:28Z callum $
+ $Id$
  */
 
 #ifdef HAVE_CONFIG_H
@@ -434,7 +434,7 @@ battery_full_notify (GtkWidget *applet)
 
 	/* XXX: it would be nice to pass this as a named icon */
 	notify_notification_set_icon_from_pixbuf (n, icon);
-	gdk_pixbuf_unref (icon);
+	g_object_unref (icon);
 
 	result = notify_notification_show (n, &error);
 	
@@ -1018,11 +1018,11 @@ check_for_updates( gpointer data )
   {
     int timeout;
 
-    /* if on AC and not even driven scale back the polls to once every 10 */
+    /* if on AC and not event driven scale back the polls to once every 10 */
     if (info.on_ac_power)
-      timeout = 10000;
+      timeout = 10;
     else
-      timeout = 1000;
+      timeout = 2;
 
     if (timeout != battstat->timeout)
     {
@@ -1031,7 +1031,7 @@ check_for_updates( gpointer data )
       if (battstat->timeout_id)
         g_source_remove (battstat->timeout_id);
 
-      battstat->timeout_id = g_timeout_add (battstat->timeout,
+      battstat->timeout_id = g_timeout_add_seconds (battstat->timeout,
                                             check_for_updates,
                                             battstat);
     }
@@ -1560,12 +1560,12 @@ create_layout(ProgressData *battstat)
      reference to each widget.  This adds a real reference to each widget
      and "sinks" the floating reference.
   */
-  gtk_widget_ref( battstat->status );
-  gtk_widget_ref( battstat->percent );
-  gtk_widget_ref( battstat->battery );
-  gtk_object_sink( GTK_OBJECT( battstat->status ) );
-  gtk_object_sink( GTK_OBJECT( battstat->percent ) );
-  gtk_object_sink( GTK_OBJECT( battstat->battery ) );
+  g_object_ref( battstat->status );
+  g_object_ref( battstat->percent );
+  g_object_ref( battstat->battery );
+  g_object_ref_sink( GTK_OBJECT( battstat->status ) );
+  g_object_ref_sink( GTK_OBJECT( battstat->percent ) );
+  g_object_ref_sink( GTK_OBJECT( battstat->battery ) );
 
   /* Let reconfigure_layout know that the table is currently empty. */
   battstat->layout.status = LAYOUT_NONE;
