@@ -1,4 +1,4 @@
-/* $Id: main.c 11193 2009-01-14 07:56:46Z diegoe $ */
+/* $Id$ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -10,8 +10,9 @@
  *
  */
 
-#  include <config.h>
-
+#include <glib.h>
+#include <config.h>
+#include <gtk/gtk.h>
 #include <panel-applet.h>
 
 #define GWEATHER_I_KNOW_THIS_IS_UNSTABLE
