@@ -36,9 +36,6 @@
 
 #include <gconf/gconf-client.h>
 
-#include <libgnomeui/gnome-help.h>
-#include <libgnome/gnome-desktop-item.h>
-
 #include "applet.h"
 #include "keys.h"
 #include "preferences.h"
@@ -46,6 +43,10 @@
 #define IS_PANEL_HORIZONTAL(o) \
   (o == PANEL_APPLET_ORIENT_UP || o == PANEL_APPLET_ORIENT_DOWN)
 
+/* This is defined is load.c, we're doing this instead of creating a load.h file
+ * because nothing else is exported. */
+GList * gnome_volume_applet_create_mixer_collection (void);
+
 static void	gnome_volume_applet_class_init	(GnomeVolumeAppletClass *klass);
 static void	gnome_volume_applet_init	(GnomeVolumeApplet *applet);
 static void	gnome_volume_applet_dispose	(GObject   *object);
@@ -56,11 +57,14 @@ static void     gnome_volume_applet_size_allocate (GtkWidget     *widget,
 static void	gnome_volume_applet_popup_dock	(GnomeVolumeApplet *applet);
 static void	gnome_volume_applet_popdown_dock (GnomeVolumeApplet *applet);
 
-static gboolean	gnome_volume_applet_scroll	(GtkWidget *widget,
+/* This function and gnome_volume_applet_key are not static so we can
+ * inject external events into the applet. Its to work around a GTK+
+ * misfeature. See dock.c for details. */
+gboolean	gnome_volume_applet_scroll	(GtkWidget *widget,
 						 GdkEventScroll *event);
 static gboolean	gnome_volume_applet_button	(GtkWidget *widget,
 						 GdkEventButton *event);
-static gboolean	gnome_volume_applet_key		(GtkWidget *widget,
+gboolean	gnome_volume_applet_key		(GtkWidget *widget,
 						 GdkEventKey *event);
 static gdouble  gnome_volume_applet_get_volume  (GstMixer *mixer, 
 						 GstMixerTrack *track);
@@ -253,12 +257,8 @@ select_tracks (GstElement *element,
   active_track_name_list = NULL;
 
   if (reset_state) {
-#ifdef HAVE_GST10
     gst_element_set_state (element, GST_STATE_READY);
     if (gst_element_get_state(element, NULL, NULL, -1) != GST_STATE_CHANGE_SUCCESS)
-#else
-    if (gst_element_set_state (element, GST_STATE_READY) != GST_STATE_SUCCESS)
-#endif
       return NULL;
   }
 
@@ -689,12 +689,6 @@ gnome_volume_applet_toggle_mute (GnomeVolumeApplet *applet)
 			        "/commands/Mute",
 			        "state", newmute ? "1" : "0", NULL);
 
-  /* Update the dock. */
-  if (applet->dock) {
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (applet->dock->mute), 
-				  newmute);
-  }
-
   /* update graphic - this should happen automagically after the next
    * idle call, but apparently doesn't for some people... */
   gnome_volume_applet_refresh (applet, TRUE, -1, newmute);
@@ -707,22 +701,10 @@ gnome_volume_applet_toggle_mute (GnomeVolumeApplet *applet)
 void
 gnome_volume_applet_run_mixer (GnomeVolumeApplet *applet)
 {
-  GnomeDesktopItem *ditem;
   GError *error = NULL;
 
-  if ((ditem = gnome_desktop_item_new_from_basename ("gnome-volume-control.desktop", 0, NULL))) {
-    gnome_desktop_item_set_launch_time (ditem, gtk_get_current_event_time ());
-    gnome_desktop_item_launch_on_screen (ditem, NULL,
-	                                 GNOME_DESKTOP_ITEM_LAUNCH_ONLY_ONE,
-					 gtk_widget_get_screen (GTK_WIDGET (applet)),
-					 -1, &error);
-    gnome_desktop_item_unref (ditem);
-  }
-  else {
-    gdk_spawn_command_line_on_screen (
-	      gtk_widget_get_screen (GTK_WIDGET (applet)),
-	      "gnome-volume-control", &error);
-  }
+  gdk_spawn_command_line_on_screen (gtk_widget_get_screen (GTK_WIDGET (applet)),
+				    "gnome-volume-control", &error);
 
   if (error) {
     GtkWidget *dialog;
@@ -742,7 +724,11 @@ gnome_volume_applet_run_mixer (GnomeVolumeApplet *applet)
  * Control events, change volume and so on.
  */
 
-static gboolean
+/* This is not static so we can inject external events
+ * into the applet. Its to work around a GTK+ misfeature. See dock.c 
+ * for details. */
+
+gboolean
 gnome_volume_applet_scroll (GtkWidget      *widget,
 			    GdkEventScroll *event)
 {
@@ -808,7 +794,7 @@ gnome_volume_applet_button (GtkWidget      *widget,
             if (applet->mixer) {
               gnome_volume_applet_popdown_dock (applet);
             }
-            gnome_volume_applet_run_mixer (applet);
+            gnome_volume_applet_toggle_mute (applet);
             return TRUE;
           default:
             break;
@@ -832,7 +818,11 @@ gnome_volume_applet_button (GtkWidget      *widget,
   return FALSE;
 }
 
-static gboolean
+/* This is not static so we can inject external events
+ * into the applet. Its to work around a GTK+ misfeature. See dock.c 
+ * for details. */
+
+gboolean
 gnome_volume_applet_key (GtkWidget   *widget,
 			 GdkEventKey *event)
 {
@@ -903,6 +893,15 @@ gnome_volume_applet_key (GtkWidget   *widget,
   return GTK_WIDGET_CLASS (parent_class)->key_press_event (widget, event);
 }
 
+static gboolean
+gnome_volume_applet_dock_focus_out (GtkWidget *dock, GdkEventFocus *event,
+				    GnomeVolumeApplet *applet)
+{
+  gnome_volume_applet_popdown_dock (applet);
+
+  return FALSE;
+}
+
 /*
  * Change orientation or size of panel.
  */
@@ -917,9 +916,13 @@ gnome_volume_applet_orientation	(PanelApplet *_applet,
   if (applet->dock) {
     gtk_widget_destroy (GTK_WIDGET (applet->dock));
   }
-  dock = gnome_volume_applet_dock_new (IS_PANEL_HORIZONTAL (orientation) ?
-				       GTK_ORIENTATION_VERTICAL : GTK_ORIENTATION_HORIZONTAL,
+  dock = gnome_volume_applet_dock_new (GTK_ORIENTATION_VERTICAL,
 				       applet);
+  g_object_ref_sink (dock); /* It isn't a child, but we do own it. */
+  gtk_widget_add_events (dock, GDK_FOCUS_CHANGE_MASK);
+  g_signal_connect (G_OBJECT (dock), "focus-out-event",
+		    G_CALLBACK (gnome_volume_applet_dock_focus_out),
+		    applet);
   applet->dock = GNOME_VOLUME_APPLET_DOCK (dock);
   gnome_volume_applet_dock_change (applet->dock, applet->adjustment);
 
@@ -967,7 +970,7 @@ gnome_volume_applet_background (PanelApplet *_applet,
   gtk_widget_set_style (GTK_WIDGET (applet), NULL);
   rc_style = gtk_rc_style_new ();
   gtk_widget_modify_style (GTK_WIDGET (applet), rc_style);
-  gtk_rc_style_unref (rc_style);
+  g_object_unref (rc_style);
 
   switch (type) {
     case PANEL_NO_BACKGROUND:
@@ -1136,6 +1139,11 @@ gnome_volume_applet_refresh (GnomeVolumeApplet *applet,
 
     gtk_image_set_from_pixbuf (applet->image, pixbuf);
     applet->state = STATE (volume, mute);
+
+    if (applet->dock) {
+      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (applet->dock->mute), 
+				    mute);
+    }
   }
 
   if (!did_change || !applet->mixer)
@@ -1299,6 +1307,9 @@ cb_gconf (GConfClient *client,
   }
   key += strlen (keyroot);
   g_free (keyroot);
+  
+  g_list_free(applet->elements);
+  applet->elements = gnome_volume_applet_create_mixer_collection ();
 
   if ((value = gconf_entry_get_value (entry)) != NULL &&
       (value->type == GCONF_VALUE_STRING) &&
@@ -1314,12 +1325,8 @@ cb_gconf (GConfClient *client,
 
           if (new_element != old_element) {
             /* change element */
-#ifdef HAVE_GST10
             gst_element_set_state (item->data, GST_STATE_READY);
             if (gst_element_get_state (item->data, NULL, NULL, -1) != GST_STATE_CHANGE_SUCCESS)
-#else
-            if (gst_element_set_state (item->data, GST_STATE_READY) != GST_STATE_SUCCESS)
-#endif
               continue;
 	    
             /* save */
@@ -1388,9 +1395,10 @@ cb_verb (BonoboUIComponent *uic,
   } else if (!strcmp (verbname, "Help")) {
     GError *error = NULL;
 
-    gnome_help_display_on_screen ("mixer_applet2", NULL,
-				  gtk_widget_get_screen (GTK_WIDGET (applet)),
-				  &error);
+    gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (applet)),
+		  "ghelp:mixer_applet2",
+		  gtk_get_current_event_time (),
+		  &error);
 
     if (error) {
       GtkWidget *dialog;
@@ -1411,11 +1419,7 @@ cb_verb (BonoboUIComponent *uic,
 
     char *comments = g_strdup_printf ("%s\n\n%s",
 		    _("Volume control for your GNOME Panel."),
-#ifdef HAVE_GST10
 		    _("Using GStreamer 0.10.")
-#else
-		    _("Using GStreamer 0.8.")
-#endif
 		    );
 
     gtk_show_about_dialog (NULL,
@@ -1435,6 +1439,9 @@ cb_verb (BonoboUIComponent *uic,
     } else {
       if (applet->prefs)
         return;
+  
+      g_list_free(applet->elements);
+      applet->elements = gnome_volume_applet_create_mixer_collection ();
 
       applet->prefs = gnome_volume_applet_preferences_new (PANEL_APPLET (applet),
 							   applet->elements,
